/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */

package org.ow2.petals.probes.api;

import java.util.concurrent.ThreadPoolExecutor;

import org.apache.commons.pool.impl.GenericObjectPool;
import org.ow2.petals.probes.api.probes.macro.ObjectPoolProbe;
import org.ow2.petals.probes.api.probes.macro.ThreadPoolProbe;
import org.ow2.petals.probes.api.sensor.detector.DefectCreator;

/**
 * Macro probe factory.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface MacroProbesFactory {

    /**
     * Create a macro probe about a {@link ThreadPoolExecutor}.
     * 
     * @param threadPoolAllocatedThreadsDefectCreator
     *            Defect creator used to create defects about exhaustion of the
     *            thread pool.
     */
    public ThreadPoolProbe createThreadPoolProbe(
            final DefectCreator threadPoolAllocatedThreadsDefectCreator);

    /**
     * Create a macro probe about a {@link GenericObjectPool}.
     * 
     * @param genericObjectPoolAllocatedThreadsDefectCreator
     *            Defect creator used to create defects about exhaustion of the
     *            generic object pool.
     */
    public ObjectPoolProbe createGenericObjectPoolProbe(
            final DefectCreator genericObjectPoolAllocatedThreadsDefectCreator);
}
