/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.probes;

import org.ow2.petals.probes.api.exceptions.ProbeNotInitializedException;
import org.ow2.petals.probes.api.exceptions.ProbeNotStartedException;

/**
 * <p>
 * A simple counter probe to count the number of something and storing the max reached value (that can be greater than
 * the max of instant values) since its last start.
 * </p>
 * <p>
 * <u><b>Lifecycle</b>:</u> The counter gauge value can be incremented or decremented only if the probe is started. The
 * instant value can be acceded only if the probe is started. The max and min values can be acceded even if the probe is
 * initialized or stopped. The current, max and min value are reseted when the probe starts.
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface CounterGaugeProbe extends Probe {

    /**
     * Increments the value of the counter gauge.
     * 
     * @throws ProbeNotStartedException
     *             The probe is not started.
     */
    public void inc() throws ProbeNotStartedException;

    /**
     * Decrements the value of the counter gauge.
     * 
     * @throws ProbeNotStartedException
     *             The probe is not started.
     */
    public void dec() throws ProbeNotStartedException;

    /**
     * Accessor to the current value.
     * 
     * @return The current counter value.
     * @throws ProbeNotStartedException
     *             The probe is not started.
     */
    public long getCurrentValue() throws ProbeNotStartedException;

    /**
     * Accessor to the max value.
     * 
     * @return The max counter value since the last probe start.
     * @throws ProbeNotInitializedException
     *             The probe is not initialized.
     */
    public long getMaxValue() throws ProbeNotInitializedException;

    /**
     * Accessor to the min value.
     * 
     * @return The min counter value since the last probe start.
     * @throws ProbeNotInitializedException
     *             The probe is not initialized.
     */
    public long getMinValue() throws ProbeNotInitializedException;

}
