/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.probes.macro;

import org.apache.commons.pool.impl.GenericObjectPool;
import org.ow2.petals.probes.api.exceptions.ProbeNotInitializedException;
import org.ow2.petals.probes.api.exceptions.ProbeNotStartedException;
import org.ow2.petals.probes.api.probes.Probe;

/**
 * A macro probe containing all probes needed to monitor an instance of the
 * object pool {@link GenericObjectPool}.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface ObjectPoolProbe extends Probe {

    /**
     * Set the object pool to probe
     * 
     * @param objectPool
     *            the object pool to probe
     */
    public void setObjectPool(final GenericObjectPool<?> objectPool);

    /**
     * @return The current max size of objects that the object pool can accept.
     */
    public long getObjectPoolMaxSize();

    /**
     * @return The current min size of idle objects under which the object pool
     *         will spawn new ones.
     */
    public long getObjectPoolMinIdleSize();

    /**
     * @return The max number of borrowed objects of the object pool
     */
    public long getObjectPoolBorrowedObjectsMax() throws ProbeNotInitializedException;

    /**
     * @return The current number of borrowed threads of the object pool
     */
    public long getObjectPoolBorrowedObjectsCurrent() throws ProbeNotStartedException;

    /**
     * @return The max number of idle objects of the object pool
     */
    public long getObjectPoolIdleObjectsMax() throws ProbeNotInitializedException;

    /**
     * @return The current number of idle objects of the object pool
     */
    public long getObjectPoolIdleObjectsCurrent() throws ProbeNotStartedException;

    /**
     * Realizes a measure of the thread pool:
     * <ul>
     * <li>current number of allocated threads,</li>
     * <li>current number of enqueued tasks.</li>
     * </ul>
     */
    public void pick() throws ProbeNotStartedException;

}
